summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/constants/npc_constants.asm27
-rw-r--r--src/constants/sprite_constants.asm38
-rw-r--r--src/data/map_objects.asm36
-rw-r--r--src/data/npcs.asm1375
-rw-r--r--src/engine/bank03.asm250
-rw-r--r--src/engine/bank04.asm26
-rw-r--r--src/text/text3.asm120
-rw-r--r--src/text/text_offsets.asm120
-rw-r--r--src/wram.asm2
9 files changed, 1177 insertions, 817 deletions
diff --git a/src/constants/npc_constants.asm b/src/constants/npc_constants.asm
index eb7b75b..4a64993 100644
--- a/src/constants/npc_constants.asm
+++ b/src/constants/npc_constants.asm
@@ -18,19 +18,19 @@ LOADED_NPC_LENGTH EQU const_value
; npc_struct constants
const_def
- const NPC_TRAINER_ID
- const NPC_DATA_FIELD_01 ; 01-03 Seem to relate to sprites
- const NPC_DATA_FIELD_02
+ const NPC_DATA_ID
+ const NPC_DATA_SPRITE_ID
+ const NPC_DATA_FIELD_02 ; 02-04 Seem to relate to sprites
const NPC_DATA_FIELD_03
const NPC_DATA_FIELD_04
- const NPC_DATA_OWSEQUENCE_PTR
+ const NPC_DATA_SCRIPT_PTR
const_value = const_value+1
const NPC_DATA_NAME_TEXT
const_value = const_value+1
- const NPC_DATA_BATTLE_PICTURE
- const NPC_DATA_FIELD_0A
- const NPC_DATA_FIELD_0B
- const NPC_DATA_FIELD_0C
+ const NPC_DATA_DUELIST_PICTURE
+ const NPC_DATA_DECK_ID
+ const NPC_DATA_DUEL_THEME_ID
+ const NPC_DATA_MATCH_START_ID
NPC_DATA_LENGTH EQU const_value
const_def 1
@@ -81,8 +81,8 @@ NPC_DATA_LENGTH EQU const_value
const NPC_RONALD1 ; $02
const NPC_ISHIHARA ; $03
const NPC_IMAKUNI ; $04
-const_value = const_value+1 ; DRMASON duplicate
-const_value = const_value+1 ; DRMASON duplicate
+ const NPC_05 ; $05 (unused)
+ const NPC_06 ; $06 (unused)
const NPC_SAM ; $07
const NPC_TECH1 ; $08
const NPC_TECH2 ; $09
@@ -186,10 +186,9 @@ const_value = const_value+1 ; DRMASON duplicate
const NPC_LEGENDARY_CARD_BOTTOM_LEFT ; $6b
const NPC_LEGENDARY_CARD_BOTTOM_RIGHT ; $6c
const NPC_LEGENDARY_CARD_RIGHT_SPARK ; $6d
- const NPC_11F49 ; $6e
-const_value = const_value+1 ; NPC_11F49 duplicate
+ const NPC_6E ; $6e (unused)
+ const NPC_6F ; $6f (unused)
const NPC_MURRAY2 ; $70
const NPC_RONALD2 ; $71
const NPC_RONALD3 ; $72
-const_value = const_value+1 ; NPC_11f49 duplicate
-
+ const NPC_73 ; $73 (unused)
diff --git a/src/constants/sprite_constants.asm b/src/constants/sprite_constants.asm
index dc051d9..c4d219d 100644
--- a/src/constants/sprite_constants.asm
+++ b/src/constants/sprite_constants.asm
@@ -20,3 +20,41 @@ SPRITE_ANIM_BUFFER_CAPACITY EQU 16 ; sprites
const SPRITE_ANIM_MOVEMENT_COUNTER
const SPRITE_ANIM_FIELD_0F
SPRITE_ANIM_LENGTH EQU const_value
+
+ const_def 1
+ const SPRITE_RONALD ; $01
+ const SPRITE_DRMASON ; $02
+ const SPRITE_ISHIHARA ; $03
+ const SPRITE_IMAKUNI ; $04
+ const SPRITE_NIKKI ; $05
+ const SPRITE_RICK ; $06
+ const SPRITE_KEN ; $07
+ const SPRITE_AMY ; $08
+ const SPRITE_ISAAC ; $09
+ const SPRITE_MITCH ; $0A
+ const SPRITE_GENE ; $0B
+ const SPRITE_MURRAY ; $0C
+ const SPRITE_COURTNEY ; $0D
+ const SPRITE_STEVE ; $0E
+ const SPRITE_JACK ; $0F
+ const SPRITE_ROD ; $10
+ const SPRITE_BOY1 ; $11
+ const SPRITE_BOY2 ; $12
+ const SPRITE_BOY3 ; $13
+ const SPRITE_BUTCH ; $14
+ const SPRITE_BOY4 ; $15
+ const SPRITE_JOSHUA ; $16
+ const SPRITE_BOY5 ; $17
+ const SPRITE_TECH ; $18
+ const SPRITE_CHAP ; $19
+ const SPRITE_GUIDE ; $1A
+ const SPRITE_PAPPY ; $1B
+ const SPRITE_GIRL1 ; $1C
+ const SPRITE_GIRL2 ; $1D
+ const SPRITE_GIRL3 ; $1E
+ const SPRITE_GIRL4 ; $1F
+ const SPRITE_GIRL5 ; $20
+ const SPRITE_CLERK ; $21
+ const SPRITE_HOST ; $22
+ const SPRITE_WOMAN ; $23
+ const SPRITE_GRANNY ; $24
diff --git a/src/data/map_objects.asm b/src/data/map_objects.asm
index 1ac73fa..4e2570b 100644
--- a/src/data/map_objects.asm
+++ b/src/data/map_objects.asm
@@ -240,12 +240,12 @@ FightingClubLobbyObjects: ; 13c6f (3:7c6f)
db NORTH, 6, 6
dw Script_fc52
tx Text041b
- tx Text03b0
+ tx ClerkNPCName
db NORTH, 10, 6
dw Func_fc7a
tx Text041b
- tx Text03b0
+ tx ClerkNPCName
db $ff
@@ -274,12 +274,12 @@ RockClubLobbyObjects: ; 13ca6 (3:7ca6)
db NORTH, 6, 6
dw Script_fc52
tx Text041b
- tx Text03b0
+ tx ClerkNPCName
db NORTH, 10, 6
dw Func_fc7a
tx Text041b
- tx Text03b0
+ tx ClerkNPCName
db $ff
@@ -308,12 +308,12 @@ WaterClubLobbyObjects: ; 13cdd (3:7cdd)
db NORTH, 6, 6
dw Script_fc52
tx Text041b
- tx Text03b0
+ tx ClerkNPCName
db NORTH, 10, 6
dw Func_fc7a
tx Text041b
- tx Text03b0
+ tx ClerkNPCName
db $ff
@@ -342,12 +342,12 @@ LightningClubLobbyObjects: ; 13d14 (3:7d14)
db NORTH, 6, 6
dw Script_fc52
tx Text041b
- tx Text03b0
+ tx ClerkNPCName
db NORTH, 10, 6
dw Func_fc7a
tx Text041b
- tx Text03b0
+ tx ClerkNPCName
db $ff
@@ -376,12 +376,12 @@ GrassClubLobbyObjects: ; 13d4b (3:7d4b)
db NORTH, 6, 6
dw Script_fc52
tx Text041b
- tx Text03b0
+ tx ClerkNPCName
db NORTH, 10, 6
dw Func_fc7a
tx Text041b
- tx Text03b0
+ tx ClerkNPCName
db $ff
@@ -410,12 +410,12 @@ PsychicClubLobbyObjects: ; 13d82 (3:7d82)
db NORTH, 6, 6
dw Script_fc52
tx Text041b
- tx Text03b0
+ tx ClerkNPCName
db NORTH, 10, 6
dw Func_fc7a
tx Text041b
- tx Text03b0
+ tx ClerkNPCName
db $ff
@@ -444,12 +444,12 @@ ScienceClubLobbyObjects: ; 13db9 (3:7db9)
db NORTH, 6, 6
dw Script_fc52
tx Text041b
- tx Text03b0
+ tx ClerkNPCName
db NORTH, 10, 6
dw Func_fc7a
tx Text041b
- tx Text03b0
+ tx ClerkNPCName
db $ff
@@ -478,12 +478,12 @@ FireClubLobbyObjects: ; 13df0 (3:7df0)
db NORTH, 6, 6
dw Script_fc52
tx Text041b
- tx Text03b0
+ tx ClerkNPCName
db NORTH, 10, 6
dw Func_fc7a
tx Text041b
- tx Text03b0
+ tx ClerkNPCName
db $ff
@@ -512,12 +512,12 @@ ChallengeHallLobbyObjects: ; 13e27 (3:7e27)
db NORTH, 6, 6
dw Script_fc52
tx Text041b
- tx Text03b0
+ tx ClerkNPCName
db NORTH, 10, 6
dw Func_fc7a
tx Text041b
- tx Text03b0
+ tx ClerkNPCName
db $ff
diff --git a/src/data/npcs.asm b/src/data/npcs.asm
index 99979ce..7880a8b 100644
--- a/src/data/npcs.asm
+++ b/src/data/npcs.asm
@@ -1,1409 +1,1520 @@
; When you press the A button in front of something it will find a data entry somewhere on this list
; it will then jump to the pointer in the data item. All jumps lead to an RST20 operation.
; The Deck IDs are used for the challenge hall
-NPCDataTable:
- dw DrMasonData
- dw DrMasonData
- dw Ronald1Data
- dw IshiharaData
- dw ImakuniData
- dw DrMasonData
- dw DrMasonData
- dw SamData
- dw Tech1Data
- dw Tech2Data
- dw Tech3Data
- dw Tech4Data
- dw Tech5Data
- dw Tech6Data
- dw Clerk1Data
- dw Clerk2Data
- dw Clerk3Data
- dw Clerk4Data
- dw Clerk5Data
- dw Clerk6Data
- dw Clerk7Data
- dw Clerk8Data
- dw Clerk9Data
- dw ChrisData
- dw MichaelData
- dw JessicaData
- dw MitchData
- dw MatthewData
- dw RyanData
- dw AndrewData
- dw GeneData
- dw SaraData
- dw AmandaData
- dw JoshuaData
- dw AmyData
- dw JenniferData
- dw NicholasData
- dw BrandonData
- dw IsaacData
- dw BrittanyData
- dw KristinData
- dw HeatherData
- dw NikkiData
- dw RobertData
- dw DanielData
- dw StephanieData
- dw Murray1Data
- dw JosephData
- dw DavidData
- dw ErikData
- dw RickData
- dw JohnData
- dw AdamData
- dw JonathanData
- dw KenData
- dw CourtneyData
- dw SteveData
- dw JackData
- dw RodData
- dw Clerk10Data
- dw GiftCenterClerkData
- dw Man1Data
- dw Woman1Data
- dw Chap1Data
- dw Gal1Data
- dw Lass1Data
- dw Chap2Data
- dw Lass2Data
- dw Pappy1Data
- dw Lad1Data
- dw Lad2Data
- dw Chap3Data
- dw Clerk12Data
- dw Clerk13Data
- dw HostData
- dw Specs1Data
- dw ButchData
- dw Granny1Data
- dw Lass3Data
- dw Man2Data
- dw Pappy2Data
- dw Lass4Data
- dw Hood1Data
- dw Granny2Data
- dw Gal2Data
- dw Lad3Data
- dw Gal3Data
- dw Chap4Data
- dw Man3Data
- dw Specs2Data
- dw Specs3Data
- dw Woman2Data
- dw ManiaData
- dw Pappy3Data
- dw Gal4Data
- dw ChampData
- dw Hood2Data
- dw Lass5Data
- dw Chap5Data
- dw AaronData
- dw GuideData
- dw Tech7Data
- dw Tech8Data
- dw Data_11f18 ; these actually are used for the effects around the legendary cards
- dw Data_11f1f
- dw Data_11f26
- dw Data_11f2d
- dw Data_11f34
- dw Data_11f3b
- dw Data_11f42
- dw Data_11f49
- dw Data_11f49
- dw Murray2Data
- dw Ronald2Data
- dw Ronald3Data
- dw Data_11f49
-DrMasonData:
+NPCHeaderPointers:
+ dw DrMasonNPCHeader
+ dw DrMasonNPCHeader
+ dw Ronald1NPCHeader
+ dw IshiharaNPCHeader
+ dw ImakuniNPCHeader
+ dw DrMasonNPCHeader
+ dw DrMasonNPCHeader
+ dw SamNPCHeader
+ dw Tech1NPCHeader
+ dw Tech2NPCHeader
+ dw Tech3NPCHeader
+ dw Tech4NPCHeader
+ dw Tech5NPCHeader
+ dw Tech6NPCHeader
+ dw Clerk1NPCHeader
+ dw Clerk2NPCHeader
+ dw Clerk3NPCHeader
+ dw Clerk4NPCHeader
+ dw Clerk5NPCHeader
+ dw Clerk6NPCHeader
+ dw Clerk7NPCHeader
+ dw Clerk8NPCHeader
+ dw Clerk9NPCHeader
+ dw ChrisNPCHeader
+ dw MichaelNPCHeader
+ dw JessicaNPCHeader
+ dw MitchNPCHeader
+ dw MatthewNPCHeader
+ dw RyanNPCHeader
+ dw AndrewNPCHeader
+ dw GeneNPCHeader
+ dw SaraNPCHeader
+ dw AmandaNPCHeader
+ dw JoshuaNPCHeader
+ dw AmyNPCHeader
+ dw JenniferNPCHeader
+ dw NicholasNPCHeader
+ dw BrandonNPCHeader
+ dw IsaacNPCHeader
+ dw BrittanyNPCHeader
+ dw KristinNPCHeader
+ dw HeatherNPCHeader
+ dw NikkiNPCHeader
+ dw RobertNPCHeader
+ dw DanielNPCHeader
+ dw StephanieNPCHeader
+ dw Murray1NPCHeader
+ dw JosephNPCHeader
+ dw DavidNPCHeader
+ dw ErikNPCHeader
+ dw RickNPCHeader
+ dw JohnNPCHeader
+ dw AdamNPCHeader
+ dw JonathanNPCHeader
+ dw KenNPCHeader
+ dw CourtneyNPCHeader
+ dw SteveNPCHeader
+ dw JackNPCHeader
+ dw RodNPCHeader
+ dw Clerk10NPCHeader
+ dw GiftCenterClerkNPCHeader
+ dw Man1NPCHeader
+ dw Woman1NPCHeader
+ dw Chap1NPCHeader
+ dw Gal1NPCHeader
+ dw Lass1NPCHeader
+ dw Chap2NPCHeader
+ dw Lass2NPCHeader
+ dw Pappy1NPCHeader
+ dw Lad1NPCHeader
+ dw Lad2NPCHeader
+ dw Chap3NPCHeader
+ dw Clerk12NPCHeader
+ dw Clerk13NPCHeader
+ dw HostNPCHeader
+ dw Specs1NPCHeader
+ dw ButchNPCHeader
+ dw Granny1NPCHeader
+ dw Lass3NPCHeader
+ dw Man2NPCHeader
+ dw Pappy2NPCHeader
+ dw Lass4NPCHeader
+ dw Hood1NPCHeader
+ dw Granny2NPCHeader
+ dw Gal2NPCHeader
+ dw Lad3NPCHeader
+ dw Gal3NPCHeader
+ dw Chap4NPCHeader
+ dw Man3NPCHeader
+ dw Specs2NPCHeader
+ dw Specs3NPCHeader
+ dw Woman2NPCHeader
+ dw ManiaNPCHeader
+ dw Pappy3NPCHeader
+ dw Gal4NPCHeader
+ dw ChampNPCHeader
+ dw Hood2NPCHeader
+ dw Lass5NPCHeader
+ dw Chap5NPCHeader
+ dw AaronNPCHeader
+ dw GuideNPCHeader
+ dw Tech7NPCHeader
+ dw Tech8NPCHeader
+ dw TorchNPCHeader
+ dw LegendaryCardTopLeftNPCHeader
+ dw LegendaryCardTopRightNPCHeader
+ dw LegendaryCardLeftSparkNPCHeader
+ dw LegendaryCardBottomLeftNPCHeader
+ dw LegendaryCardBottomRightNPCHeader
+ dw LegendaryCardRightSparkNPCHeader
+ dw DummyNPCHeader
+ dw DummyNPCHeader
+ dw Murray2NPCHeader
+ dw Ronald2NPCHeader
+ dw Ronald3NPCHeader
+ dw DummyNPCHeader
+
+DrMasonNPCHeader:
db NPC_DRMASON
- db $02
+ db SPRITE_DRMASON
db $00
- db $26
+ db $26 ; palette and animation
db $00
- dw $5727 ; Pointer to Script
- tx Text03ac
+ dw Script_DrMason
+ tx DrMasonNPCName
db $00
db $00
db $00
db $00
-Ronald1Data:
+
+Ronald1NPCHeader:
db NPC_RONALD1
- db $01
+ db SPRITE_RONALD
db $04
db $0e
db $00
- dw Script_Ronald ; Pointer to Script
- tx Text03ad
+ dw Script_Ronald
+ tx RonaldNPCName
db RONALD_PIC
db INVINCIBLE_RONALD_DECK_ID
- db $0f
- db $16
-Ronald2Data:
+ db MUSIC_RONALD
+ db MUSIC_MATCH_START_2
+
+Ronald2NPCHeader:
db NPC_RONALD2
- db $01
+ db SPRITE_RONALD
db $04
db $0e
db $00
- dw Script_Ronald ; Pointer to Script
- tx Text03ad
+ dw Script_Ronald
+ tx RonaldNPCName
db RONALD_PIC
db INVINCIBLE_RONALD_DECK_ID
- db $0f
- db $16
-Ronald3Data:
+ db MUSIC_RONALD
+ db MUSIC_MATCH_START_2
+
+Ronald3NPCHeader:
db NPC_RONALD3
- db $01
+ db SPRITE_RONALD
db $04
db $0e
db $00
- dw Script_Ronald ; Pointer to Script
- tx Text03ad
+ dw Script_Ronald
+ tx RonaldNPCName
db RONALD_PIC
db INVINCIBLE_RONALD_DECK_ID
- db $0f
- db $16
-IshiharaData:
+ db MUSIC_RONALD
+ db MUSIC_MATCH_START_2
+
+IshiharaNPCHeader:
db NPC_ISHIHARA
- db $03
+ db SPRITE_ISHIHARA
db $04
db $22
db $00
- dw Script_Ishihara ; Pointer to Script
- tx Text03ae
+ dw Script_Ishihara
+ tx IshiharaNPCName
db $00
db $00
db $00
db $00
-ImakuniData:
+
+ImakuniNPCHeader:
db NPC_IMAKUNI
- db $04
+ db SPRITE_IMAKUNI
db $00
db $0e
db $00
- dw Script_Imakuni ; Pointer to Script
- tx Text03af
+ dw Script_Imakuni
+ tx ImakuniNPCName
db IMAKUNI_PIC
db IMAKUNI_DECK_ID
- db $10
- db $15
-SamData:
+ db MUSIC_IMAKUNI
+ db MUSIC_MATCH_START_1
+
+SamNPCHeader:
db NPC_SAM
- db $18
+ db SPRITE_TECH
db $00
db $0e
db $00
- dw $561d ; Pointer to Script
- tx Text03b1
+ dw Script_Sam
+ tx SamNPCName
db SAM_PIC
db SAMS_NORMAL_DECK_ID
- db $02
- db $15
-Tech1Data:
+ db MUSIC_DUEL_THEME_1
+ db MUSIC_MATCH_START_1
+
+Tech1NPCHeader:
db NPC_TECH1
- db $18
+ db SPRITE_TECH
db $00
db $0e
db $00
- dw $5583 ; Pointer to Script
- tx Text03b2
+ dw Script_Tech1
+ tx TechNPCName
db $00
db $00
db $00
db $00
-Tech2Data:
+
+Tech2NPCHeader:
db NPC_TECH2
- db $18
+ db SPRITE_TECH
db $00
db $0e
db $00
- dw $55ca ; Pointer to Script
- tx Text03b2
+ dw Script_Tech2
+ tx TechNPCName
db $00
db $00
db $00
db $00
-Tech3Data:
+
+Tech3NPCHeader:
db NPC_TECH3
- db $18
+ db SPRITE_TECH
db $00
db $0e
db $00
- dw $55d5 ; Pointer to Script
- tx Text03b2
+ dw Script_Tech3
+ tx TechNPCName
db $00
db $00
db $00
db $00
-Tech4Data:
+
+Tech4NPCHeader:
db NPC_TECH4
- db $18
+ db SPRITE_TECH
db $00
db $0e
db $00
- dw $55e0 ; Pointer to Script
- tx Text03b2
+ dw Script_Tech4
+ tx TechNPCName
db $00
db $00
db $00
db $00
-Tech5Data:
+
+Tech5NPCHeader:
db NPC_TECH5
- db $18
+ db SPRITE_TECH
db $00
db $0e
db $00
- dw $55f9 ; Pointer to Script
- tx Text03b2
+ dw Script_Tech5
+ tx TechNPCName
db $00
db $00
db $00
db $00
-Tech6Data:
+
+Tech6NPCHeader:
db NPC_TECH6
- db $18
+ db SPRITE_TECH
db $00
db $0e
db $00
- dw $58bb ; Pointer to Script
- tx Text03b2
+ dw Script_Tech6
+ tx TechNPCName
db $00
db $00
db $00
db $00
-Clerk1Data:
+
+Clerk1NPCHeader:
db NPC_CLERK1
- db $21
+ db SPRITE_CLERK
db $0a
db $30
db $00
- dw Script_Clerk1 ; Pointer to Script
- tx Text03b3
+ dw Script_Clerk1
+ tx ClerkNPCName2
db $00
db $00
db $00
db $00
-Clerk2Data:
+
+Clerk2NPCHeader:
db NPC_CLERK2
- db $21
+ db SPRITE_CLERK
db $0a
db $30
db $00
- dw $5ed1 ; Pointer to Script
- tx Text03b3
+ dw Script_Clerk2
+ tx ClerkNPCName2
db $00
db $00
db $00
db $00
-Clerk3Data:
+
+Clerk3NPCHeader:
db NPC_CLERK3
- db $21
+ db SPRITE_CLERK
db $0a
db $30
db $00
- dw $609e ; Pointer to Script
- tx Text03b3
+ dw Script_Clerk3
+ tx ClerkNPCName2
db $00
db $00
db $00
db $00
-Clerk4Data:
+
+Clerk4NPCHeader:
db NPC_CLERK4
- db $21
+ db SPRITE_CLERK
db $0a
db $30
db $00
- dw $6369 ; Pointer to Script
- tx Text03b3
+ dw Script_Clerk4
+ tx ClerkNPCName2
db $00
db $00
db $00
db $00
-Clerk5Data:
+
+Clerk5NPCHeader:
db NPC_CLERK5
- db $21
+ db SPRITE_CLERK
db $0a
db $30
db $00
- dw $6566 ; Pointer to Script
- tx Text03b3
+ dw Script_Clerk5
+ tx ClerkNPCName2
db $00
db $00
db $00
db $00
-Clerk6Data:
+
+Clerk6NPCHeader:
db NPC_CLERK6
- db $21
+ db SPRITE_CLERK
db $0a
db $30
db $00
- dw $684c ; Pointer to Script
- tx Text03b3
+ dw Script_Clerk6
+ tx ClerkNPCName2
db $00
db $00
db $00
db $00
-Clerk7Data:
+
+Clerk7NPCHeader:
db NPC_CLERK7
- db $21
+ db SPRITE_CLERK
db $0a
db $30
db $00
- dw $6b53 ; Pointer to Script
- tx Text03b3
+ dw Script_Clerk7
+ tx ClerkNPCName2
db $00
db $00
db $00
db $00
-Clerk8Data:
+
+Clerk8NPCHeader:
db NPC_CLERK8
- db $21
+ db SPRITE_CLERK
db $0a
db $30
db $00
- dw $6d45 ; Pointer to Script
- tx Text03b3
+ dw Script_Clerk8
+ tx ClerkNPCName2
db $00
db $00
db $00
db $00
-Clerk9Data:
+
+Clerk9NPCHeader:
db NPC_CLERK9
- db $21
+ db SPRITE_CLERK
db $0a
db $30
db $00
- dw Script_Clerk9 ; Pointer to Script
- tx Text03b3
+ dw Script_Clerk9
+ tx ClerkNPCName2
db $00
db $00
db $00
db $00
-ChrisData:
+
+ChrisNPCHeader:
db NPC_CHRIS
- db $15
+ db SPRITE_BOY4
db $00
db $26
db $00
- dw $5ef2 ; Pointer to Script
- tx Text03b4
+ dw Script_Chris
+ tx ChrisNPCName
db CHRIS_PIC
db MUSCLES_FOR_BRAINS_DECK_ID
- db $03
- db $15
-MichaelData:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_1
+
+MichaelNPCHeader:
db NPC_MICHAEL
- db $15
+ db SPRITE_BOY4
db $00
db $26
db $00
- dw $6573 ; Pointer to Script
- tx Text03b5
+ dw Script_Michael
+ tx MichaelNPCName
db MICHAEL_PIC
db HEATED_BATTLE_DECK_ID
- db $03
- db $15
-JessicaData:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_1
+
+JessicaNPCHeader:
db NPC_JESSICA
- db $1f
+ db SPRITE_GIRL4
db $04
db $1a
db $00
- dw $6d96 ; Pointer to Script
- tx Text03b6
+ dw Script_Jessica
+ tx JessicaNPCName
db JESSICA_PIC
db LOVE_TO_BATTLE_DECK_ID
- db $03
- db $15
-MitchData:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_1
+
+MitchNPCHeader:
db NPC_MITCH
- db $0a
+ db SPRITE_MITCH
db $00
db $0e
db $00
- dw $5dc3 ; Pointer to Script
- tx Text03b7
+ dw Script_Mitch
+ tx MitchNPCName
db MITCH_PIC
db FIRST_STRIKE_DECK_ID
- db $03
- db $16
-MatthewData:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_2
+
+MatthewNPCHeader:
db NPC_MATTHEW
- db $15
+ db SPRITE_BOY4
db $00
db $16
db $00
- dw $5f39 ; Pointer to Script
- tx Text03b8
+ dw Script_Matthew
+ tx MatthewNPCName
db MATTHEW_PIC
db HARD_POKEMON_DECK_ID
- db $03
- db $15
-RyanData:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_1
+
+RyanNPCHeader:
db NPC_RYAN
- db $11
+ db SPRITE_BOY1
db $00
db $26
db $00
- dw $5ff0 ; Pointer to Script
- tx Text03b9
+ dw Script_Ryan
+ tx RyanNPCName
db RYAN_PIC
db EXCAVATION_DECK_ID
- db $03
- db $15
-AndrewData:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_1
+
+AndrewNPCHeader:
db NPC_ANDREW
- db $1a
+ db SPRITE_GUIDE
db $00
db $16
db $00
- dw $6017 ; Pointer to Script
- tx Text03ba
+ dw Script_Andrew
+ tx AndrewNPCName
db ANDREW_PIC
db BLISTERING_POKEMON_DECK_ID
- db $03
- db $15
-GeneData:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_1
+
+GeneNPCHeader:
db NPC_GENE
- db $0b
+ db SPRITE_GENE
db $04
db $1e
db $00
- dw $603e ; Pointer to Script
- tx Text03bb
+ dw Script_Gene
+ tx GeneNPCName
db GENE_PIC
db ROCK_CRUSHER_DECK_ID
- db $03
- db $16
-SaraData:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_2
+
+SaraNPCHeader:
db NPC_SARA
- db $20
+ db SPRITE_GIRL5
db $00
db $0e
db $00
- dw Script_Sara ; Pointer to Script
- tx Text03bc
+ dw Script_Sara
+ tx SaraNPCName
db SARA_PIC
db WATERFRONT_POKEMON_DECK_ID
- db $03
- db $15
-AmandaData:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_1
+
+AmandaNPCHeader:
db NPC_AMANDA
- db $20
+ db SPRITE_GIRL5
db $00
db $16
db $00
- dw Script_Amanda ; Pointer to Script
- tx Text03bd
- db AMANDA_PIC ; battle profile picture
+ dw Script_Amanda
+ tx AmandaNPCName
+ db AMANDA_PIC
db LONELY_FRIENDS_DECK_ID
- db $03
- db $15
-JoshuaData:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_1
+
+JoshuaNPCHeader:
db NPC_JOSHUA
- db $16
+ db SPRITE_JOSHUA
db $00
db $26
db $00
- dw Script_Joshua ; Pointer to Script
- tx Text03be
+ dw Script_Joshua
+ tx JoshuaNPCName
db JOSHUA_PIC
db SOUND_OF_THE_WAVES_DECK_ID
- db $03
- db $15
-AmyData:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_1
+
+AmyNPCHeader:
db NPC_AMY
- db $08
+ db SPRITE_AMY
db $08
db $2e
db $10
- dw Script_Amy ; Pointer to Script
- tx Text03bf
+ dw Script_Amy
+ tx AmyNPCName
db AMY_PIC
db GO_GO_RAIN_DANCE_DECK_ID
- db $03
- db $16
-JenniferData:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_2
+
+JenniferNPCHeader:
db NPC_JENNIFER
- db $1c
+ db SPRITE_GIRL1
db $04
db $0e
db $00
- dw $6408 ; Pointer to Script
- tx Text03c0
+ dw Script_Jennifer
+ tx JenniferNPCName
db JENNIFER_PIC
db PIKACHU_DECK_ID
- db $03
- db $15
-NicholasData:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_1
+
+NicholasNPCHeader:
db NPC_NICHOLAS
- db $17
+ db SPRITE_BOY5
db $04
db $1e
db $00
- dw $642f ; Pointer to Script
- tx Text03c1
+ dw Script_Nicholas
+ tx NicholasNPCName
db NICHOLAS_PIC
db BOOM_BOOM_SELFDESTRUCT_DECK_ID
- db $03
- db $15
-BrandonData:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_1
+
+BrandonNPCHeader:
db NPC_BRANDON
- db $17
+ db SPRITE_BOY5
db $04
db $1e
db $00
- dw $6456 ; Pointer to Script
- tx Text03c2
+ dw Script_Brandon
+ tx BrandonNPCName
db BRANDON_PIC
db POWER_GENERATOR_DECK_ID
- db $03
- db $15
-IsaacData:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_1
+
+IsaacNPCHeader:
db NPC_ISAAC
- db $09
+ db SPRITE_ISAAC
db $00
db $16
db $00
- dw $64ad ; Pointer to Script
- tx Text03c3
+ dw Script_Isaac
+ tx IsaacNPCName
db ISAAC_PIC
db ZAPPING_SELFDESTRUCT_DECK_ID
- db $03
- db $16
-BrittanyData:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_2
+
+BrittanyNPCHeader:
db NPC_BRITTANY
- db $1c
+ db SPRITE_GIRL1
db $04
db $0e
db $00
- dw Script_Brittany ; Pointer to Script
- tx Text03c4
+ dw Script_Brittany
+ tx BrittanyNPCName
db BRITTANY_PIC
db ETCETERA_DECK_ID
- db $03
- db $15
-KristinData:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_1
+
+KristinNPCHeader:
db NPC_KRISTIN
- db $1e
+ db SPRITE_GIRL3
db $00
db $1e
db $00
- dw $6701 ; Pointer to Script
- tx Text03c5
+ dw Script_Kristin
+ tx KristinNPCName
db KRISTIN_PIC
db FLOWER_GARDEN_DECK_ID
- db $03
- db $15
-HeatherData:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_1
+
+HeatherNPCHeader:
db NPC_HEATHER
- db $1d
+ db SPRITE_GIRL2
db $04
db $22
db $00
- dw $6745 ; Pointer to Script
- tx Text03c6
+ dw Script_Heather
+ tx HeatherNPCName
db HEATHER_PIC
db KALEIDOSCOPE_DECK_ID
- db $03
- db $15
-NikkiData:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_1
+
+NikkiNPCHeader:
db NPC_NIKKI
- db $05
+ db SPRITE_NIKKI
db $00
db $1a
db $00
- dw $679e ; Pointer to Script
- tx Text03c7
+ dw Script_Nikki
+ tx NikkiNPCName
db NIKKI_PIC
db FLOWER_POWER_DECK_ID
- db $03
- db $16
-RobertData:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_2
+
+RobertNPCHeader:
db NPC_ROBERT
- db $11
+ db SPRITE_BOY1
db $04
db $16
db $00
- dw $6980 ; Pointer to Script
- tx Text03c8
+ dw Script_Robert
+ tx RobertNPCName
db ROBERT_PIC
db GHOST_DECK_ID
- db $03
- db $15
-DanielData:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_1
+
+DanielNPCHeader:
db NPC_DANIEL
- db $12
+ db SPRITE_BOY2
db $04
db $1a
db $00
- dw $6a60 ; Pointer to Script
- tx Text03c9
+ dw Script_Daniel
+ tx DanielNPCName
db DANIEL_PIC
db NAP_TIME_DECK_ID
- db $03
- db $15
-StephanieData:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_1
+
+StephanieNPCHeader:
db NPC_STEPHANIE
- db $1c
+ db SPRITE_GIRL1
db $04
db $0e
db $00
- dw $6aa2 ; Pointer to Script
- tx Text03ca
+ dw Script_Stephanie
+ tx StephanieNPCName
db STEPHANIE_PIC
db STRANGE_POWER_DECK_ID
- db $03
- db $15
-Murray1Data:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_1
+
+Murray1NPCHeader:
db NPC_MURRAY1
- db $0c
+ db SPRITE_MURRAY
db $00
db $12
db $00
- dw $6adf ; Pointer to Script
- tx Text03cb
+ dw Script_Murray1
+ tx MurrayNPCName
db MURRAY_PIC
db STRANGE_PSYSHOCK_DECK_ID
- db $03
- db $16
-Murray2Data:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_2
+
+Murray2NPCHeader:
db NPC_MURRAY2
- db $0c
+ db SPRITE_MURRAY
db $03
db $15
db $10
- dw $6adf ; Pointer to Script
- tx Text03cb
+ dw Script_Murray2
+ tx MurrayNPCName
db MURRAY_PIC
db STRANGE_PSYSHOCK_DECK_ID
- db $03
- db $16
-JosephData:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_2
+
+JosephNPCHeader:
db NPC_JOSEPH
- db $18
+ db SPRITE_TECH
db $00
db $0e
db $00
- dw $6cdb ; Pointer to Script
- tx Text03cc
+ dw Script_Joseph
+ tx JosephNPCName
db JOSEPH_PIC
db FLYIN_POKEMON_DECK_ID
- db $03
- db $15
-DavidData:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_1
+
+DavidNPCHeader:
db NPC_DAVID
- db $18
+ db SPRITE_TECH
db $00
db $0e
db $00
- dw $6c11 ; Pointer to Script
- tx Text03cd
+ dw Script_David
+ tx DavidNPCName
db DAVID_PIC
db LOVELY_NIDORAN_DECK_ID
- db $03
- db $15
-ErikData:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_1
+
+ErikNPCHeader:
db NPC_ERIK
- db $18
+ db SPRITE_TECH
db $00
db $0e
db $00
- dw $6c42 ; Pointer to Script
- tx Text03ce
+ dw Script_Erik
+ tx ErikNPCName
db ERIK_PIC
db POISON_DECK_ID
- db $03
- db $15
-RickData:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_1
+
+RickNPCHeader:
db NPC_RICK
- db $06
+ db SPRITE_RICK
db $00
db $0e
db $00
- dw $6c67 ; Pointer to Script
- tx Text03cf
+ dw Script_Rick
+ tx RickNPCName
db RICK_PIC
db WONDERS_OF_SCIENCE_DECK_ID
- db $03
- db $16
-JohnData:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_2
+
+JohnNPCHeader:
db NPC_JOHN
- db $12
+ db SPRITE_BOY2
db $04
db $1a
db $00
- dw $6eb3 ; Pointer to Script
- tx Text03d0
+ dw Script_John
+ tx JohnNPCName
db JOHN_PIC
db ANGER_DECK_ID
- db $03
- db $15
-AdamData:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_1
+
+AdamNPCHeader:
db NPC_ADAM
- db $13
+ db SPRITE_BOY3
db $00
db $22
db $00
- dw $6ed8 ; Pointer to Script
- tx Text03d1
+ dw Script_Adam
+ tx AdamNPCName
db ADAM_PIC
db FLAMETHROWER_DECK_ID
- db $03
- db $15
-JonathanData:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_1
+
+JonathanNPCHeader:
db NPC_JONATHAN
- db $11
+ db SPRITE_BOY1
db $04
db $16
db $00
- dw $6efd ; Pointer to Script
- tx Text03d2
+ dw Script_Jonathan
+ tx JonathanNPCName
db JONATHAN_PIC
db RESHUFFLE_DECK_ID
- db $03
- db $15
-KenData:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_1
+
+KenNPCHeader:
db NPC_KEN
- db $07
+ db SPRITE_KEN
db $04
db $1e
db $00
- dw $6f22 ; Pointer to Script
- tx Text03d3
+ dw Script_Ken
+ tx KenNPCName
db KEN_PIC
db FIRE_CHARGE_DECK_ID
- db $03
- db $16
-CourtneyData:
+ db MUSIC_DUEL_THEME_2
+ db MUSIC_MATCH_START_2
+
+CourtneyNPCHeader:
db NPC_COURTNEY
- db $0d
+ db SPRITE_COURTNEY
db $00
db $12
db $00
- dw $771f ; Pointer to Script
- tx Text03d4
+ dw Script_Courtney
+ tx CourtneyNPCName
db COURTNEY_PIC
db LEGENDARY_MOLTRES_DECK_ID
- db $04
- db $17
-SteveData:
+ db MUSIC_DUEL_THEME_3
+ db MUSIC_MATCH_START_3
+
+SteveNPCHeader:
db NPC_STEVE
- db $0e
+ db SPRITE_STEVE
db $00
db $2a
db $00
- dw $772a ; Pointer to Script
- tx Text03d5
+ dw Script_Steve
+ tx SteveNPCName
db STEVE_PIC
db LEGENDARY_ZAPDOS_DECK_ID
- db $04
- db $17
-JackData:
+ db MUSIC_DUEL_THEME_3
+ db MUSIC_MATCH_START_3
+
+JackNPCHeader:
db NPC_JACK
- db $0f
+ db SPRITE_JACK
db $00
db $26
db $00
- dw $7735 ; Pointer to Script
- tx Text03d6
+ dw Script_Jack
+ tx JackNPCName
db JACK_PIC
db LEGENDARY_ARTICUNO_DECK_ID
- db $04
- db $17
-RodData:
+ db MUSIC_DUEL_THEME_3
+ db MUSIC_MATCH_START_3
+
+RodNPCHeader:
db NPC_ROD
- db $10
+ db SPRITE_ROD
db $00
db $0e
db $00
- dw $7740 ; Pointer to Script
- tx Text03d7
+ dw Script_Rod
+ tx RodNPCName
db ROD_PIC
db LEGENDARY_DRAGONITE_DECK_ID
- db $04
- db $17
-Clerk10Data:
+ db MUSIC_DUEL_THEME_3
+ db MUSIC_MATCH_START_3
+
+Clerk10NPCHeader:
db NPC_CLERK10
- db $21
+ db SPRITE_CLERK
db $0a
db $30
db $00
- dw NoOverworldSequence ; Pointer to Script
- tx Text03b0
+ dw Script_Clerk10
+ tx ClerkNPCName
db $00
db $00
db $00
db $00
-GiftCenterClerkData:
+
+GiftCenterClerkNPCHeader:
db NPC_GIFT_CENTER_CLERK
- db $21
+ db SPRITE_CLERK
db $0a
db $30
db $00
- dw NoOverworldSequence ; Pointer to Script
- tx Text03b0
+ dw Script_GiftCenterClerk
+ tx ClerkNPCName
db $00
db $00
db $00
db $00
-Man1Data:
+
+Man1NPCHeader:
db NPC_MAN1
- db $1a
+ db SPRITE_GUIDE
db $00
db $16
db $00
- dw $5c76 ; Pointer to Script
- tx Text03d8
+ dw Script_Man1
+ tx ManNPCName
db $00
db $00
db $00
db $00
-Woman1Data:
+
+Woman1NPCHeader:
db NPC_WOMAN1
- db $23
+ db SPRITE_WOMAN
db $04
db $1e
db $00
- dw $5f83 ; Pointer to Script
- tx Text03d9
+ dw Script_Woman1
+ tx WomanNPCName
db $00
db $00
db $00
db $00
-Chap1Data:
+
+Chap1NPCHeader:
db NPC_CHAP1
- db $19
+ db SPRITE_CHAP
db $00
db $1a
db $00
- dw $5fc0 ; Pointer to Script
- tx Text03da
+ dw Script_Chap1
+ tx ChapNPCName
db $00
db $00
db $00
db $00
-Gal1Data:
+
+Gal1NPCHeader:
db NPC_GAL1
- db $22
+ db SPRITE_HOST
db $00
db $16
db $00
- dw Script_Gal1 ; Pointer to Script
- tx Text03db
+ dw Script_Gal1
+ tx GalNPCName
db $00
db $00
db $00
db $00
-Lass1Data:
+
+Lass1NPCHeader:
db NPC_LASS1
- db $1e
+ db SPRITE_GIRL3
db $00
db $1e
db $00
- dw Script_Lass1 ; Pointer to Script
- tx Text03dc
+ dw Script_Lass1
+ tx LassNPCName
db $00
db $00
db $00
db $00
-Chap2Data:
+
+Chap2NPCHeader:
db NPC_CHAP2
- db $19
+ db SPRITE_CHAP
db $00
db $1a
db $00
- dw $639a ; Pointer to Script
- tx Text03da
+ dw Script_Chap2
+ tx ChapNPCName
db $00
db $00
db $00
db $00
-Lass2Data:
+
+Lass2NPCHeader:
db NPC_LASS2
- db $1e
+ db SPRITE_GIRL3
db $00
db $1e
db $00
- dw Script_e61f ; Pointer to Script
- tx Text03dc
+ dw Script_Lass2
+ tx LassNPCName
db $00
db $00
db $00
db $00
-Pappy1Data:
+
+Pappy1NPCHeader:
db NPC_PAPPY1
- db $1b
+ db SPRITE_PAPPY
db $00
db $22
db $00
- dw $69a5 ; Pointer to Script
- tx Text03dd
+ dw Script_Pappy1
+ tx PappyNPCName
db $00
db $00
db $00
db $00
-Lad1Data:
+
+Lad1NPCHeader:
db NPC_LAD1
- db $12
+ db SPRITE_BOY2
db $04
db $1a
db $00
- dw $6b84 ; Pointer to Script
- tx Text03de
+ dw Script_Lad1
+ tx LadNPCName
db $00
db $00
db $00
db $00
-Lad2Data:
+
+Lad2NPCHeader:
db NPC_LAD2
- db $11
+ db SPRITE_BOY1
db $04
db $16
db $00
- dw $6e2c ; Pointer to Script
- tx Text03de
+ dw Script_Lad2
+ tx LadNPCName
db $00
db $00
db $00
db $00
-Chap3Data:
+
+Chap3NPCHeader:
db NPC_CHAP3
- db $19
+ db SPRITE_CHAP
db $00
db $1a
db $00
- dw $6de8 ; Pointer to Script
- tx Text03da
+ dw Script_Chap3
+ tx ChapNPCName
db $00
db $00
db $00
db $00
-Clerk12Data:
+
+Clerk12NPCHeader:
db NPC_CLERK12
- db $22
+ db SPRITE_HOST
db $00
db $16
db $00
- dw Script_Clerk12 ; Pointer to Script
- tx Text03b3
+ dw Script_Clerk12
+ tx ClerkNPCName2
db $00
db $00
db $00
db $00
-Clerk13Data:
+
+Clerk13NPCHeader:
db NPC_CLERK13
- db $22
+ db SPRITE_HOST
db $00
db $16
db $00
- dw Script_Clerk13 ; Pointer to Script
- tx Text03b3
+ dw Script_Clerk13
+ tx ClerkNPCName2
db $00
db $00
db $00
db $00
-HostData:
+
+HostNPCHeader:
db NPC_HOST
- db $22
+ db SPRITE_HOST
db $00
db $16
db $00
- dw Script_HostStubbed ; Pointer to Script
- tx Text03df
+ dw Script_Host
+ tx HostNPCName
db $00
db $00
db $00
db $00
-Specs1Data:
+
+Specs1NPCHeader:
db NPC_SPECS1
- db $13
+ db SPRITE_BOY3
db $00
db $22
db $00
- dw $5d82 ; Pointer to Script
- tx Text03e0
+ dw Script_Specs1
+ tx SpecsNPCName
db $00
db $00
db $00
db $00
-ButchData:
+
+ButchNPCHeader:
db NPC_BUTCH
- db $14
+ db SPRITE_BUTCH
db $00
db $16
db $00
- dw $5d8d ; Pointer to Script
- tx Text03e1
+ dw Script_Butch
+ tx ButchNPCName
db $00
db $00
db $00
db $00
-Granny1Data:
+
+Granny1NPCHeader:
db NPC_GRANNY1
- db $24
+ db SPRITE_GRANNY
db $00
db $16
db $00
- dw $5d9f ; Pointer to Script
- tx Text03e5
+ dw Script_Granny1
+ tx GrannyNPCName
db $00
db $00
db $00
db $00
-Lass3Data:
+
+Lass3NPCHeader:
db NPC_LASS3
- db $1d
+ db SPRITE_GIRL2
db $04
db $22
db $00
- dw $5fd2 ; Pointer to Script
- tx Text03dc
+ dw Script_Lass3
+ tx LassNPCName
db $00
db $00
db $00
db $00
-Man2Data:
+
+Man2NPCHeader:
db NPC_MAN2
- db $1a
+ db SPRITE_GUIDE
db $00
db $16
db $00
- dw Script_Man2 ; Pointer to Script
- tx Text03d8
+ dw Script_Man2
+ tx ManNPCName
db $00
db $00
db $00
db $00
-Pappy2Data:
+
+Pappy2NPCHeader:
db NPC_PAPPY2
- db $1b
+ db SPRITE_PAPPY
db $00
db $22
db $00
- dw Script_Pappy2 ; Pointer to Script
- tx Text03dd
+ dw Script_Pappy2
+ tx PappyNPCName
db $00
db $00
db $00
db $00
-Lass4Data:
+
+Lass4NPCHeader:
db NPC_LASS4
- db $1d
+ db SPRITE_GIRL2
db $04
db $22
db $00
- dw $63d9 ; Pointer to Script
- tx Text03dc
+ dw Script_Lass4
+ tx LassNPCName
db $00
db $00
db $00
db $00
-Hood1Data:
+
+Hood1NPCHeader:
db NPC_HOOD1
- db $17
+ db SPRITE_BOY5
db $04
db $1e
db $00
- dw $63dd ; Pointer to Script
- tx Text03e2
+ dw Script_Hood1
+ tx HoodNPCName
db $00
db $00
db $00
db $00
-Granny2Data:
+
+Granny2NPCHeader:
db NPC_GRANNY2
- db $24
+ db SPRITE_GRANNY
db $00
db $16
db $00
- dw $66d8 ; Pointer to Script
- tx Text03e5
+ dw Script_Granny2
+ tx GrannyNPCName
db $00
db $00
db $00
db $00
-Gal2Data:
+
+Gal2NPCHeader:
db NPC_GAL2
- db $22
+ db SPRITE_HOST
db $00
db $16
db $00
- dw $66e3 ; Pointer to Script
- tx Text03db
+ dw Script_Gal2
+ tx GalNPCName
db $00
db $00
db $00
db $00
-Lad3Data:
+
+Lad3NPCHeader:
db NPC_LAD3
- db $12
+ db SPRITE_BOY2
db $04
db $1a
db $00
- dw $6850 ; Pointer to Script
- tx Text03de
+ dw Script_Lad3
+ tx LadNPCName
db $00
db $00
db $00
db $00
-Gal3Data:
+
+Gal3NPCHeader:
db NPC_GAL3
- db $22
+ db SPRITE_HOST
db $00
db $16
db $00
- dw $6a30 ; Pointer to Script
- tx Text03db
+ dw Script_Gal3
+ tx GalNPCName
db $00
db $00
db $00
db $00
-Chap4Data:
+
+Chap4NPCHeader:
db NPC_CHAP4
- db $19
+ db SPRITE_CHAP
db $00
db $1a
db $00
- dw $6a3b ; Pointer to Script
- tx Text03da
+ dw Script_Chap4
+ tx ChapNPCName
db $00
db $00
db $00
db $00
-Man3Data:
+
+Man3NPCHeader:
db NPC_MAN3
- db $1a
+ db SPRITE_GUIDE
db $00
db $16
db $00
- dw $6bc1 ; Pointer to Script
- tx Text03d8
+ dw Script_Man3
+ tx ManNPCName
db $00
db $00
db $00
db $00
-Specs2Data:
+
+Specs2NPCHeader:
db NPC_SPECS2
- db $18
+ db SPRITE_TECH
db $00
db $0e
db $00
- dw $6bc5 ; Pointer to Script
- tx Text03e0
+ dw Script_Specs2
+ tx SpecsNPCName
db $00
db $00
db $00
db $00
-Specs3Data:
+
+Specs3NPCHeader:
db NPC_SPECS3
- db $13
+ db SPRITE_BOY3
db $00
db $22
db $00
- dw $6bed ; Pointer to Script
- tx Text03e0
+ dw Script_Specs3
+ tx SpecsNPCName
db $00
db $00
db $00
db $00
-Woman2Data:
+
+Woman2NPCHeader:
db NPC_WOMAN2
- db $23
+ db SPRITE_WOMAN
db $04
db $1e
db $00
- dw NoOverworldSequence ; Pointer to Script
- tx Text03d9
+ dw Script_Woman2
+ tx WomanNPCName
db $00
db $00
db $00
db $00
-ManiaData:
+
+ManiaNPCHeader:
db NPC_MANIA
- db $15
+ db SPRITE_BOY4
db $00
db $26
db $00
- dw $6e88 ; Pointer to Script
- tx Text03e4
+ dw Script_Mania
+ tx ManiaNPCName
db $00
db $00
db $00
db $00
-Pappy3Data:
+
+Pappy3NPCHeader:
db NPC_PAPPY3
- db $1b
+ db SPRITE_PAPPY
db $00
db $22
db $00
- dw Script_Pappy3 ; Pointer to Script
- tx Text03dd
+ dw Script_Pappy3
+ tx PappyNPCName
db $00
db $00
db $00
db $00
-Gal4Data:
+
+Gal4NPCHeader:
db NPC_GAL4
- db $22
+ db SPRITE_HOST
db $00
db $16
db $00
- dw Script_Gal4 ; Pointer to Script
- tx Text03db
+ dw Script_Gal4
+ tx GalNPCName
db $00
db $00
db $00
db $00
-ChampData:
+
+ChampNPCHeader:
db NPC_CHAMP
- db $15
+ db SPRITE_BOY4
db $00
db $26
db $00
- dw Script_Champ ; Pointer to Script
- tx Text03e3
+ dw Script_Champ
+ tx ChampNPCName
db $00
db $00
db $00
db $00
-Hood2Data:
+
+Hood2NPCHeader:
db NPC_HOOD2
- db $17
+ db SPRITE_BOY5
db $04
db $1e
db $00
- dw Script_Hood2 ; Pointer to Script
- tx Text03e2
+ dw Script_Hood2
+ tx HoodNPCName
db $00
db $00
db $00
db $00
-Lass5Data:
+
+Lass5NPCHeader:
db NPC_LASS5
- db $1f
+ db SPRITE_GIRL4
db $04
db $1a
db $00
- dw Script_Lass5 ; Pointer to Script
- tx Text03dc
+ dw Script_Lass5
+ tx LassNPCName
db $00
db $00
db $00
db $00
-Chap5Data:
+
+Chap5NPCHeader:
db NPC_CHAP5
- db $19
+ db SPRITE_CHAP
db $00
db $1a
db $00
- dw Script_Chap5 ; Pointer to Script
- tx Text03da
+ dw Script_Chap5
+ tx ChapNPCName
db $00
db $00
db $00
db $00
-AaronData:
+
+AaronNPCHeader:
db NPC_AARON
- db $18
+ db SPRITE_TECH
db $00
db $0e
db $00
- dw $58dd ; Pointer to Script
- tx Text03e7
+ dw Script_Aaron
+ tx AaronNPCName
db AARON_PIC
db LIGHTNING_AND_FIRE_DECK_ID
- db $02
- db $15
-GuideData:
+ db MUSIC_DUEL_THEME_1
+ db MUSIC_MATCH_START_1
+
+GuideNPCHeader:
db NPC_GUIDE
- db $1a
+ db SPRITE_GUIDE
db $00
db $16
db $00
- dw Script_Guide ; Pointer to Script
- tx Text03e6
+ dw Script_Guide
+ tx GuideNPCName
db $00
db $00
db $00
db $00
-Tech7Data:
+
+Tech7NPCHeader:
db NPC_TECH7
- db $18
+ db SPRITE_TECH
db $00
db $0e
db $00
- dw $58c6 ; Pointer to Script
- tx Text03b2
+ dw Script_Tech7
+ tx TechNPCName
db $00
db $00
db $00
db $00
-Tech8Data:
+
+Tech8NPCHeader:
db NPC_TECH8
- db $18
+ db SPRITE_TECH
db $00
db $0e
db $00
- dw $58d1 ; Pointer to Script
- tx Text03b2
+ dw Script_Tech8
+ tx TechNPCName
db $00
db $00
db $00
db $00
-Data_11f18:
+
+TorchNPCHeader:
db NPC_TORCH
db $26
db $3a
db $3a
db $10
- dw NoOverworldSequence ; Pointer to Script
-Data_11f1f:
+ dw Script_Torch
+
+LegendaryCardTopLeftNPCHeader:
db NPC_LEGENDARY_CARD_TOP_LEFT
db $27
db $3b
db $41
db $50
- dw NoOverworldSequence ; Pointer to Script
-Data_11f26:
+ dw Script_LegendaryCardTopLeft
+
+LegendaryCardTopRightNPCHeader:
db NPC_LEGENDARY_CARD_TOP_RIGHT
db $27
db $3c
db $42
db $50
- dw NoOverworldSequence ; Pointer to Script
-Data_11f2d:
+ dw Script_LegendaryCardTopRight
+
+LegendaryCardLeftSparkNPCHeader:
db NPC_LEGENDARY_CARD_LEFT_SPARK
db $27
db $3d
db $43
db $50
- dw NoOverworldSequence ; Pointer to Script
-Data_11f34:
+ dw Script_LegendaryCardLeftSpark
+
+LegendaryCardBottomLeftNPCHeader:
db NPC_LEGENDARY_CARD_BOTTOM_LEFT
db $27
db $3e
db $44
db $50
- dw NoOverworldSequence ; Pointer to Script
-Data_11f3b:
+ dw Script_LegendaryCardBottomLeft
+
+LegendaryCardBottomRightNPCHeader:
db NPC_LEGENDARY_CARD_BOTTOM_RIGHT
db $27
db $3f
db $45
db $50
- dw NoOverworldSequence ; Pointer to Script
-Data_11f42:
+ dw Script_LegendaryCardBottomRight
+
+LegendaryCardRightSparkNPCHeader:
db NPC_LEGENDARY_CARD_RIGHT_SPARK
db $27
db $40
db $46
db $50
- dw NoOverworldSequence ; Pointer to Script
-Data_11f49:
+ dw Script_LegendaryCardRightSpark
+
+DummyNPCHeader:
db $00
db $00
db $00
diff --git a/src/engine/bank03.asm b/src/engine/bank03.asm
index 07e903e..4febfe9 100644
--- a/src/engine/bank03.asm
+++ b/src/engine/bank03.asm
@@ -1734,7 +1734,16 @@ Func_cc32: ; cc32 (3:4c32)
; Used for things that are represented as NPCs but don't have a Script
; EX: Clerks and legendary cards that interact through Level Objects
-NoOverworldSequence: ; cc3e (3:4c3e)
+Script_Clerk10: ; cc3e (3:4c3e)
+Script_GiftCenterClerk: ; cc3e (3:4c3e)
+Script_Woman2: ; cc3e (3:4c3e)
+Script_Torch: ; cc3e (3:4c3e)
+Script_LegendaryCardTopLeft: ; cc3e (3:4c3e)
+Script_LegendaryCardTopRight: ; cc3e (3:4c3e)
+Script_LegendaryCardLeftSpark: ; cc3e (3:4c3e)
+Script_LegendaryCardBottomLeft: ; cc3e (3:4c3e)
+Script_LegendaryCardBottomRight: ; cc3e (3:4c3e)
+Script_LegendaryCardRightSpark: ; cc3e (3:4c3e)
call CloseAdvancedDialogueBox
ret
@@ -3208,7 +3217,26 @@ Script_ChallengeMachine: ; d57d (3:557d)
run_command Func_d43d
run_command ScriptCommand_QuitScriptFully
- INCROM $d583, $d753
+Script_Tech1: ; d583 (3:5583)
+ INCROM $d583, $d5ca
+
+Script_Tech2: ; d5ca (3:55ca)
+ INCROM $d5ca, $d5d5
+
+Script_Tech3: ; d5d5 (3:55d5)
+ INCROM $d5d5, $d5e0
+
+Script_Tech4: ; d5e0 (3:55e0)
+ INCROM $d5e0, $d5f9
+
+Script_Tech5: ; d5f9 (3:55f9)
+ INCROM $d5f9, $d61d
+
+Script_Sam: ; d61d (3:561d)
+ INCROM $d61d, $d727
+
+Script_DrMason: ; d727 (3:5727)
+ INCROM $d727, $d753
Script_EnterLabFirstTime: ; d753 (3:5753)
start_script
@@ -3448,7 +3476,19 @@ NPCMovement_d894: ; d894 (4:5894)
db SOUTH | NO_MOVE
db $ff
- INCROM $d896, $d932
+ INCROM $d896, $d8bb
+
+Script_Tech6: ; d8bb (3:58bb)
+ INCROM $d8bb, $d8c6
+
+Script_Tech7: ; d8c6 (3:58c6)
+ INCROM $d8c6, $d8d1
+
+Script_Tech8: ; d8d1 (3:58d1)
+ INCROM $d8d1, $d8dd
+
+Script_Aaron: ; d8dd (3:58dd)
+ INCROM $d8dd, $d932
Script_d932: ; d932 (3:5932)
start_script
@@ -3766,6 +3806,7 @@ FightingClubLobbyAfterDuel: ; dc68 (3:5c68)
dw Script_LostToImakuni
db $00
+Script_Man1: ; dc76 (3:5c76)
INCROM $dc76, $dd0d
Script_Imakuni: ; dd0d (3:5d0d)
@@ -3888,7 +3929,47 @@ NPCMovement_dd78 ; dd78 (3:5d78)
db EAST
db $ff
- INCROM $dd82, $e0b0
+Script_Specs1: ; dd82 (3:5d82)
+ INCROM $dd82, $dd8d
+
+Script_Butch: ; dd8d (3:5d8d)
+ INCROM $dd8d, $dd9f
+
+Script_Granny1: ; dd9f (3:5d9f)
+ INCROM $dd9f, $ddc3
+
+Script_Mitch: ; ddc3 (3:5dc3)
+ INCROM $ddc3, $ded1
+
+Script_Clerk2: ; ded1 (3:5ed1)
+ INCROM $ded1, $def2
+
+Script_Chris: ; def2 (3:5ef2)
+ INCROM $def2, $df39
+
+Script_Matthew: ; df39 (3:5f39)
+ INCROM $df39, $df83
+
+Script_Woman1: ; df83 (3:5f83)
+ INCROM $df83, $dfc0
+
+Script_Chap1: ; dfc0 (3:5fc0)
+ INCROM $dfc0, $dfd2
+
+Script_Lass3: ; dfd2 (3:5fd2)
+ INCROM $dfd2, $dff0
+
+Script_Ryan: ; dff0 (3:5ff0)
+ INCROM $dff0, $e017
+
+Script_Andrew: ; e017 (3:6017)
+ INCROM $e017, $e03e
+
+Script_Gene: ; e03e (3:603e)
+ INCROM $e03e, $e09e
+
+Script_Clerk3: ; e09e (3:609e)
+ INCROM $e09e, $e0b0
Preload_ImakuniInWaterClubLobby: ; e0b0 (3:60b0)
get_flag_value EVENT_IMAKUNI_STATE
@@ -4525,7 +4606,29 @@ ScriptJump_TalkToAmyAgain: ; e356 (3:6356)
run_command ScriptCommand_QuitScriptFully
; 0xe369
- INCROM $e369, $e525
+Script_Clerk4: ; e369 (3:6369)
+ INCROM $e369, $e39a
+
+Script_Chap2: ; e39a (3:639a)
+ INCROM $e39a, $e3d9
+
+Script_Lass4: ; e3d9 (3:63d9)
+ INCROM $e3d9, $e3dd
+
+Script_Hood1: ; e3dd (3:63dd)
+ INCROM $e3dd, $e408
+
+Script_Jennifer: ; e408 (3:6408)
+ INCROM $e408, $e42f
+
+Script_Nicholas: ; e42f (3:642f)
+ INCROM $e42f, $e456
+
+Script_Brandon: ; e456 (3:6456)
+ INCROM $e456, $e4ad
+
+Script_Isaac: ; e4ad (3:64ad)
+ INCROM $e4ad, $e525
GrassClubEntranceAfterDuel: ; e525 (3:6525)
ld hl, GrassClubEntranceAfterDuelTable
@@ -4580,7 +4683,11 @@ GrassClubEntranceAfterDuelTable: ; e553 (3:6553)
dw Script_LostToSecondRonaldFight
db $00
- INCROM $e566, $e5c4
+Script_Clerk5: ; e566 (3:6566)
+ INCROM $e566, $e573
+
+Script_Michael: ; e573 (3:6573)
+ INCROM $e573, $e5c4
GrassClubLobbyAfterDuel: ; e5c4 (3:65c4)
ld hl, .after_duel_table
@@ -4639,13 +4746,13 @@ Script_BeatBrittany: ; e5ee (3:65ee)
run_command ScriptCommand_JumpIfFlagNotLessThan
db EVENT_FLAG_35
db $02
- dw .finishSequence
+ dw .finishScript
run_command ScriptCommand_JumpIfFlagZero2
db EVENT_FLAG_3A
- dw .finishSequence
+ dw .finishScript
run_command ScriptCommand_JumpIfFlagZero2
db EVENT_FLAG_3B
- dw .finishSequence
+ dw .finishScript
run_command ScriptCommand_SetFlagValue
db EVENT_FLAG_35
db $01
@@ -4653,7 +4760,7 @@ Script_BeatBrittany: ; e5ee (3:65ee)
db EVENT_FLAG_1E
run_command ScriptCommand_PrintTextString
tx Text06e8
-.finishSequence
+.finishScript
run_command ScriptCommand_QuitScriptFully
Script_LostToBrittany: ; e618 (3:6618)
@@ -4666,7 +4773,7 @@ Script_e61c: ; e61c (3:661c)
run_command ScriptCommand_PrintTextQuitFully
tx Text06ea
-Script_e61f: ; e61f (3:661f)
+Script_Lass2: ; e61f (3:661f)
start_script
run_command ScriptCommand_JumpIfFlagNonzero2
db EVENT_FLAG_04
@@ -4833,7 +4940,20 @@ Script_e61f: ; e61f (3:661f)
tx Text06f3
; 0xe6d8
- INCROM $e6d8, $e7f6
+Script_Granny2: ; e6d8 (3:66d8)
+ INCROM $e6d8, $e6e3
+
+Script_Gal2: ; e6e3 (3:66e3)
+ INCROM $e6e3, $e701
+
+Script_Kristin: ; e701 (3:6701)
+ INCROM $e701, $e745
+
+Script_Heather: ; e745 (3:6745)
+ INCROM $e745, $e79e
+
+Script_Nikki: ; e79e (3:679e)
+ INCROM $e79e, $e7f6
ClubEntranceAfterDuel: ; e7f6 (3:67f6)
ld hl, .after_duel_table
@@ -4852,7 +4972,7 @@ ClubEntranceAfterDuel: ; e7f6 (3:67f6)
db $00
; A Ronald is already loaded or not loaded depending on Pre-Load scripts
-; in data/npc_map_data.asm. This just starts a sequence if possible.
+; in data/npc_map_data.asm. This just starts a script if possible.
LoadClubEntrance: ; e809 (3:6809)
call TryFirstRonaldFight
call TrySecondRonaldFight
@@ -4890,7 +5010,11 @@ TrySecondRonaldFight: ; e837 (3:6837)
jp SetNextNPCAndScript
; 0xe84c
- INCROM $e84c, $e862
+Script_Clerk6: ; e84c (3:684c)
+ INCROM $e84c, $e850
+
+Script_Lad3: ; e850 (3:6850)
+ INCROM $e850, $e862
Script_FirstRonaldEncounter: ; e862 (3:6862)
start_script
@@ -5109,7 +5233,61 @@ ScriptJump_FinishedSecondRonaldFight ; e959 (3:6959)
run_command ScriptCommand_QuitScriptFully
; 0xe963
- INCROM $e963, $ed57
+ INCROM $e963, $e980
+
+Script_Robert: ; e980 (3:6980)
+ INCROM $e980, $e9a5
+
+Script_Pappy1: ; e9a5 (3:69a5)
+ INCROM $e9a5, $ea30
+
+Script_Gal3: ; ea30 (3:6a30)
+ INCROM $ea30, $ea3b
+
+Script_Chap4: ; ea3b (3:6a3b)
+ INCROM $ea3b, $ea60
+
+Script_Daniel: ; ea60 (3:6a60)
+ INCROM $ea60, $eaa2
+
+Script_Stephanie: ; eaa2 (3:6aa2)
+ INCROM $eaa2, $eadf
+
+Script_Murray2: ; eadf (3:6adf)
+ INCROM $eadf, $eadf
+
+Script_Murray1: ; eadf (3:6adf)
+ INCROM $eadf, $eb53
+
+Script_Clerk7: ; eb53 (3:6b53)
+ INCROM $eb53, $eb84
+
+Script_Lad1: ; eb84 (3:6b84)
+ INCROM $eb84, $ebc1
+
+Script_Man3: ; ebc1 (3:6bc1)
+ INCROM $ebc1, $ebc5
+
+Script_Specs2: ; ebc5 (3:6bc5)
+ INCROM $ebc5, $ebed
+
+Script_Specs3: ; ebed (3:6bed)
+ INCROM $ebed, $ec11
+
+Script_David: ; ec11 (3:6c11)
+ INCROM $ec11, $ec42
+
+Script_Erik: ; ec42 (3:6c42)
+ INCROM $ec42, $ec67
+
+Script_Rick: ; ec67 (3:6c67)
+ INCROM $ec67, $ecdb
+
+Script_Joseph: ; ecdb (3:6cdb)
+ INCROM $ecdb, $ed45
+
+Script_Clerk8: ; ed45 (3:6d45)
+ INCROM $ed45, $ed57
FireClubPressedA: ; ed57 (3:6d57)
ld hl, SlowpokePaintingObjectTable
@@ -5157,7 +5335,16 @@ FindExtraInteractableObjects: ; ed64 (3:6d64)
ret
; 0xed8d
- INCROM $ed8d, $ee76
+ INCROM $ed8d, $ed96
+
+Script_Jessica: ; ed96 (3:6d96)
+ INCROM $ed96, $ede8
+
+Script_Chap3: ; ede8 (3:6de8)
+ INCROM $ede8, $ee2c
+
+Script_Lad2: ; ee2c (3:6e2c)
+ INCROM $ee2c, $ee76
Script_ee76: ; ee76 (3:6e76)
start_script
@@ -5180,7 +5367,20 @@ Script_ee76: ; ee76 (3:6e76)
run_command ScriptCommand_QuitScriptFully
; 0xee88
- INCROM $ee88, $ef96
+Script_Mania: ; ee88 (3:6e88)
+ INCROM $ee88, $eeb3
+
+Script_John: ; eeb3 (3:6eb3)
+ INCROM $eeb3, $eed8
+
+Script_Adam: ; eed8 (3:6ed8)
+ INCROM $eed8, $eefd
+
+Script_Jonathan: ; eefd (3:6efd)
+ INCROM $eefd, $ef22
+
+Script_Ken: ; ef22 (3:6f22)
+ INCROM $ef22, $ef96
Preload_Clerk9: ; ef96 (3:6f96)
call TryGiveMedalPCPacks
@@ -5728,7 +5928,7 @@ NPCMovement_f34e: ; f34e (3:734e)
db SOUTH
db $ff
-Script_HostStubbed: ; f352 (3:7352)
+Script_Host: ; f352 (3:7352)
ret
Script_f353: ; f353 (3:7353)
@@ -6297,7 +6497,19 @@ Script_f631: ; f631 (3:7631)
ret
; 0xf63c
- INCROM $f63c, $fbdb
+ INCROM $f63c, $f71f
+
+Script_Courtney: ; f71f (3:771f)
+ INCROM $f71f, $f72a
+
+Script_Steve: ; f72a (3:772a)
+ INCROM $f72a, $f735
+
+Script_Jack: ; f735 (3:7735)
+ INCROM $f735, $f740
+
+Script_Rod: ; f740 (3:7740)
+ INCROM $f740, $fbdb
HallOfHonorLoadMap: ; fbdb (3:7bdb)
ld a, SFX_10
diff --git a/src/text/text3.asm b/src/text/text3.asm
index 78c22de..4d3fccf 100644
--- a/src/text/text3.asm
+++ b/src/text/text3.asm
@@ -1620,243 +1620,243 @@ Text03ab: ; 3f663 (f:7663)
text "LABORATORY"
done
-Text03ac: ; 3f66f (f:766f)
+DrMasonNPCName: ; 3f66f (f:766f)
text "Dr. Mason"
done
-Text03ad: ; 3f67a (f:767a)
+RonaldNPCName: ; 3f67a (f:767a)
text "Ronald"
done
-Text03ae: ; 3f682 (f:7682)
+IshiharaNPCName: ; 3f682 (f:7682)
text "ISHIHARA"
done
-Text03af: ; 3f68c (f:768c)
+ImakuniNPCName: ; 3f68c (f:768c)
text "Imakuni?"
done
-Text03b0: ; 3f696 (f:7696)
+ClerkNPCName: ; 3f696 (f:7696)
text "CLERK"
done
-Text03b1: ; 3f69d (f:769d)
+SamNPCName: ; 3f69d (f:769d)
text "Sam"
done
-Text03b2: ; 3f6a2 (f:76a2)
+TechNPCName: ; 3f6a2 (f:76a2)
text "TECH"
done
-Text03b3: ; 3f6a8 (f:76a8)
+ClerkNPCName2: ; 3f6a8 (f:76a8)
text "CLERK"
done
-Text03b4: ; 3f6af (f:76af)
+ChrisNPCName: ; 3f6af (f:76af)
text "Chris"
done
-Text03b5: ; 3f6b6 (f:76b6)
+MichaelNPCName: ; 3f6b6 (f:76b6)
text "Michael"
done
-Text03b6: ; 3f6bf (f:76bf)
+JessicaNPCName: ; 3f6bf (f:76bf)
text "Jessica"
done
-Text03b7: ; 3f6c8 (f:76c8)
+MitchNPCName: ; 3f6c8 (f:76c8)
text "Mitch"
done
-Text03b8: ; 3f6cf (f:76cf)
+MatthewNPCName: ; 3f6cf (f:76cf)
text "Matthew"
done
-Text03b9: ; 3f6d8 (f:76d8)
+RyanNPCName: ; 3f6d8 (f:76d8)
text "Ryan"
done
-Text03ba: ; 3f6de (f:76de)
+AndrewNPCName: ; 3f6de (f:76de)
text "Andrew"
done
-Text03bb: ; 3f6e6 (f:76e6)
+GeneNPCName: ; 3f6e6 (f:76e6)
text "Gene"
done
-Text03bc: ; 3f6ec (f:76ec)
+SaraNPCName: ; 3f6ec (f:76ec)
text "Sara"
done
-Text03bd: ; 3f6f2 (f:76f2)
+AmandaNPCName: ; 3f6f2 (f:76f2)
text "Amanda"
done
-Text03be: ; 3f6fa (f:76fa)
+JoshuaNPCName: ; 3f6fa (f:76fa)
text "Joshua"
done
-Text03bf: ; 3f702 (f:7702)
+AmyNPCName: ; 3f702 (f:7702)
text "Amy"
done
-Text03c0: ; 3f707 (f:7707)
+JenniferNPCName: ; 3f707 (f:7707)
text "Jennifer"
done
-Text03c1: ; 3f711 (f:7711)
+NicholasNPCName: ; 3f711 (f:7711)
text "Nicholas"
done
-Text03c2: ; 3f71b (f:771b)
+BrandonNPCName: ; 3f71b (f:771b)
text "Brandon"
done
-Text03c3: ; 3f724 (f:7724)
+IsaacNPCName: ; 3f724 (f:7724)
text "Isaac"
done
-Text03c4: ; 3f72b (f:772b)
+BrittanyNPCName: ; 3f72b (f:772b)
text "Brittany"
done
-Text03c5: ; 3f735 (f:7735)
+KristinNPCName: ; 3f735 (f:7735)
text "Kristin"
done
-Text03c6: ; 3f73e (f:773e)
+HeatherNPCName: ; 3f73e (f:773e)
text "Heather"
done
-Text03c7: ; 3f747 (f:7747)
+NikkiNPCName: ; 3f747 (f:7747)
text "Nikki"
done
-Text03c8: ; 3f74e (f:774e)
+RobertNPCName: ; 3f74e (f:774e)
text "Robert"
done
-Text03c9: ; 3f756 (f:7756)
+DanielNPCName: ; 3f756 (f:7756)
text "Daniel"
done
-Text03ca: ; 3f75e (f:775e)
+StephanieNPCName: ; 3f75e (f:775e)
text "Stephanie"
done
-Text03cb: ; 3f769 (f:7769)
+MurrayNPCName: ; 3f769 (f:7769)
text "Murray"
done
-Text03cc: ; 3f771 (f:7771)
+JosephNPCName: ; 3f771 (f:7771)
text "Joseph"
done
-Text03cd: ; 3f779 (f:7779)
+DavidNPCName: ; 3f779 (f:7779)
text "David"
done
-Text03ce: ; 3f780 (f:7780)
+ErikNPCName: ; 3f780 (f:7780)
text "Erik"
done
-Text03cf: ; 3f786 (f:7786)
+RickNPCName: ; 3f786 (f:7786)
text "Rick"
done
-Text03d0: ; 3f78c (f:778c)
+JohnNPCName: ; 3f78c (f:778c)
text "John"
done
-Text03d1: ; 3f792 (f:7792)
+AdamNPCName: ; 3f792 (f:7792)
text "Adam"
done
-Text03d2: ; 3f798 (f:7798)
+JonathanNPCName: ; 3f798 (f:7798)
text "Jonathan"
done
-Text03d3: ; 3f7a2 (f:77a2)
+KenNPCName: ; 3f7a2 (f:77a2)
text "Ken"
done
-Text03d4: ; 3f7a7 (f:77a7)
+CourtneyNPCName: ; 3f7a7 (f:77a7)
text "COURTNEY"
done
-Text03d5: ; 3f7b1 (f:77b1)
+SteveNPCName: ; 3f7b1 (f:77b1)
text "Steve"
done
-Text03d6: ; 3f7b8 (f:77b8)
+JackNPCName: ; 3f7b8 (f:77b8)
text "Jack"
done
-Text03d7: ; 3f7be (f:77be)
+RodNPCName: ; 3f7be (f:77be)
text "Rod"
done
-Text03d8: ; 3f7c3 (f:77c3)
+ManNPCName: ; 3f7c3 (f:77c3)
text "Man"
done
-Text03d9: ; 3f7c8 (f:77c8)
+WomanNPCName: ; 3f7c8 (f:77c8)
text "Woman"
done
-Text03da: ; 3f7cf (f:77cf)
+ChapNPCName: ; 3f7cf (f:77cf)
text "CHAP"
done
-Text03db: ; 3f7d5 (f:77d5)
+GalNPCName: ; 3f7d5 (f:77d5)
text "GAL"
done
-Text03dc: ; 3f7da (f:77da)
+LassNPCName: ; 3f7da (f:77da)
text "Lass"
done
-Text03dd: ; 3f7e0 (f:77e0)
+PappyNPCName: ; 3f7e0 (f:77e0)
text "Pappy"
done
-Text03de: ; 3f7e7 (f:77e7)
+LadNPCName: ; 3f7e7 (f:77e7)
text "Lad"
done
-Text03df: ; 3f7ec (f:77ec)
+HostNPCName: ; 3f7ec (f:77ec)
text "HOST"
done
-Text03e0: ; 3f7f2 (f:77f2)
+SpecsNPCName: ; 3f7f2 (f:77f2)
text "Specs"
done
-Text03e1: ; 3f7f9 (f:77f9)
+ButchNPCName: ; 3f7f9 (f:77f9)
text "Butch"
done
-Text03e2: ; 3f800 (f:7800)
+HoodNPCName: ; 3f800 (f:7800)
text "Hood"
done
-Text03e3: ; 3f806 (f:7806)
+ChampNPCName: ; 3f806 (f:7806)
text "Champ"
done
-Text03e4: ; 3f80d (f:780d)
+ManiaNPCName: ; 3f80d (f:780d)
text "Mania"
done
-Text03e5: ; 3f814 (f:7814)
+GrannyNPCName: ; 3f814 (f:7814)
text "Granny"
done
-Text03e6: ; 3f81c (f:781c)
+GuideNPCName: ; 3f81c (f:781c)
text "Guide"
done
-Text03e7: ; 3f823 (f:7823)
+AaronNPCName: ; 3f823 (f:7823)
text "Aaron"
done
diff --git a/src/text/text_offsets.asm b/src/text/text_offsets.asm
index d027768..2f29a11 100644
--- a/src/text/text_offsets.asm
+++ b/src/text/text_offsets.asm
@@ -941,66 +941,66 @@ TextOffsets:: ; 34000 (d:40
textpointer Text03a9 ; 0x03a9
textpointer Text03aa ; 0x03aa
textpointer Text03ab ; 0x03ab
- textpointer Text03ac ; 0x03ac
- textpointer Text03ad ; 0x03ad
- textpointer Text03ae ; 0x03ae
- textpointer Text03af ; 0x03af
- textpointer Text03b0 ; 0x03b0
- textpointer Text03b1 ; 0x03b1
- textpointer Text03b2 ; 0x03b2
- textpointer Text03b3 ; 0x03b3
- textpointer Text03b4 ; 0x03b4
- textpointer Text03b5 ; 0x03b5
- textpointer Text03b6 ; 0x03b6
- textpointer Text03b7 ; 0x03b7
- textpointer Text03b8 ; 0x03b8
- textpointer Text03b9 ; 0x03b9
- textpointer Text03ba ; 0x03ba
- textpointer Text03bb ; 0x03bb
- textpointer Text03bc ; 0x03bc
- textpointer Text03bd ; 0x03bd
- textpointer Text03be ; 0x03be
- textpointer Text03bf ; 0x03bf
- textpointer Text03c0 ; 0x03c0
- textpointer Text03c1 ; 0x03c1
- textpointer Text03c2 ; 0x03c2
- textpointer Text03c3 ; 0x03c3
- textpointer Text03c4 ; 0x03c4
- textpointer Text03c5 ; 0x03c5
- textpointer Text03c6 ; 0x03c6
- textpointer Text03c7 ; 0x03c7
- textpointer Text03c8 ; 0x03c8
- textpointer Text03c9 ; 0x03c9
- textpointer Text03ca ; 0x03ca
- textpointer Text03cb ; 0x03cb
- textpointer Text03cc ; 0x03cc
- textpointer Text03cd ; 0x03cd
- textpointer Text03ce ; 0x03ce
- textpointer Text03cf ; 0x03cf
- textpointer Text03d0 ; 0x03d0
- textpointer Text03d1 ; 0x03d1
- textpointer Text03d2 ; 0x03d2
- textpointer Text03d3 ; 0x03d3
- textpointer Text03d4 ; 0x03d4
- textpointer Text03d5 ; 0x03d5
- textpointer Text03d6 ; 0x03d6
- textpointer Text03d7 ; 0x03d7
- textpointer Text03d8 ; 0x03d8
- textpointer Text03d9 ; 0x03d9
- textpointer Text03da ; 0x03da
- textpointer Text03db ; 0x03db
- textpointer Text03dc ; 0x03dc
- textpointer Text03dd ; 0x03dd
- textpointer Text03de ; 0x03de
- textpointer Text03df ; 0x03df
- textpointer Text03e0 ; 0x03e0
- textpointer Text03e1 ; 0x03e1
- textpointer Text03e2 ; 0x03e2
- textpointer Text03e3 ; 0x03e3
- textpointer Text03e4 ; 0x03e4
- textpointer Text03e5 ; 0x03e5
- textpointer Text03e6 ; 0x03e6
- textpointer Text03e7 ; 0x03e7
+ textpointer DrMasonNPCName ; 0x03ac
+ textpointer RonaldNPCName ; 0x03ad
+ textpointer IshiharaNPCName ; 0x03ae
+ textpointer ImakuniNPCName ; 0x03af
+ textpointer ClerkNPCName ; 0x03b0
+ textpointer SamNPCName ; 0x03b1
+ textpointer TechNPCName ; 0x03b2
+ textpointer ClerkNPCName2 ; 0x03b3
+ textpointer ChrisNPCName ; 0x03b4
+ textpointer MichaelNPCName ; 0x03b5
+ textpointer JessicaNPCName ; 0x03b6
+ textpointer MitchNPCName ; 0x03b7
+ textpointer MatthewNPCName ; 0x03b8
+ textpointer RyanNPCName ; 0x03b9
+ textpointer AndrewNPCName ; 0x03ba
+ textpointer GeneNPCName ; 0x03bb
+ textpointer SaraNPCName ; 0x03bc
+ textpointer AmandaNPCName ; 0x03bd
+ textpointer JoshuaNPCName ; 0x03be
+ textpointer AmyNPCName ; 0x03bf
+ textpointer JenniferNPCName ; 0x03c0
+ textpointer NicholasNPCName ; 0x03c1
+ textpointer BrandonNPCName ; 0x03c2
+ textpointer IsaacNPCName ; 0x03c3
+ textpointer BrittanyNPCName ; 0x03c4
+ textpointer KristinNPCName ; 0x03c5
+ textpointer HeatherNPCName ; 0x03c6
+ textpointer NikkiNPCName ; 0x03c7
+ textpointer RobertNPCName ; 0x03c8
+ textpointer DanielNPCName ; 0x03c9
+ textpointer StephanieNPCName ; 0x03ca
+ textpointer MurrayNPCName ; 0x03cb
+ textpointer JosephNPCName ; 0x03cc
+ textpointer DavidNPCName ; 0x03cd
+ textpointer ErikNPCName ; 0x03ce
+ textpointer RickNPCName ; 0x03cf
+ textpointer JohnNPCName ; 0x03d0
+ textpointer AdamNPCName ; 0x03d1
+ textpointer JonathanNPCName ; 0x03d2
+ textpointer KenNPCName ; 0x03d3
+ textpointer CourtneyNPCName ; 0x03d4
+ textpointer SteveNPCName ; 0x03d5
+ textpointer JackNPCName ; 0x03d6
+ textpointer RodNPCName ; 0x03d7
+ textpointer ManNPCName ; 0x03d8
+ textpointer WomanNPCName ; 0x03d9
+ textpointer ChapNPCName ; 0x03da
+ textpointer GalNPCName ; 0x03db
+ textpointer LassNPCName ; 0x03dc
+ textpointer PappyNPCName ; 0x03dd
+ textpointer LadNPCName ; 0x03de
+ textpointer HostNPCName ; 0x03df
+ textpointer SpecsNPCName ; 0x03e0
+ textpointer ButchNPCName ; 0x03e1
+ textpointer HoodNPCName ; 0x03e2
+ textpointer ChampNPCName ; 0x03e3
+ textpointer ManiaNPCName ; 0x03e4
+ textpointer GrannyNPCName ; 0x03e5
+ textpointer GuideNPCName ; 0x03e6
+ textpointer AaronNPCName ; 0x03e7
textpointer Text03e8 ; 0x03e8
textpointer Text03e9 ; 0x03e9
textpointer Text03ea ; 0x03ea
diff --git a/src/wram.asm b/src/wram.asm
index acd9638..ae0b9a2 100644
--- a/src/wram.asm
+++ b/src/wram.asm
@@ -1945,7 +1945,7 @@ wd0c4:: ; d0c4
wd0c5:: ; d0c5
ds $1
-; used to store the location of an overworld sequence, which is jumped to later
+; used to store the location of an overworld script, which is jumped to later
wNextScript:: ; d0c6
ds $2
diff --git a/src/engine/bank04.asm b/src/engine/bank04.asm
index 13df81b..26181ee 100644
--- a/src/engine/bank04.asm
+++ b/src/engine/bank04.asm
@@ -839,13 +839,13 @@ Func_115a3: ; 115a3 (4:55a3)
INCLUDE "data/map_scripts.asm"
-; loads a pointer into hl found on NPCDataTable
-GetNPCDataPointer: ; 1184a (4:584a)
+; loads a pointer into hl found on NPCHeaderPointers
+GetNPCHeaderPointer: ; 1184a (4:584a)
; this may have been a macro
rlca
- add LOW(NPCDataTable)
+ add LOW(NPCHeaderPointers)
ld l, a
- ld a, HIGH(NPCDataTable)
+ ld a, HIGH(NPCHeaderPointers)
adc $00
ld h, a
ld a, [hli]
@@ -856,7 +856,7 @@ GetNPCDataPointer: ; 1184a (4:584a)
LoadNPCSpriteData: ; 11857 (4:5857)
push hl
push bc
- call GetNPCDataPointer
+ call GetNPCHeaderPointer
ld a, [hli]
ld [wTempNPC], a
ld a, [hli]
@@ -881,8 +881,8 @@ LoadNPCSpriteData: ; 11857 (4:5857)
; Loads Name into wCurrentNPCNameTx and gets Script ptr into bc
GetNPCNameAndScript: ; 1187d (4:587d)
push hl
- call GetNPCDataPointer
- ld bc, NPC_DATA_OWSEQUENCE_PTR
+ call GetNPCHeaderPointer
+ ld bc, NPC_DATA_SCRIPT_PTR
add hl, bc
ld c, [hl]
inc hl
@@ -899,7 +899,7 @@ GetNPCNameAndScript: ; 1187d (4:587d)
SetNPCDialogName: ; 11893 (4:5893)
push hl
push bc
- call GetNPCDataPointer
+ call GetNPCHeaderPointer
ld bc, NPC_DATA_NAME_TEXT
add hl, bc
ld a, [hli]
@@ -913,7 +913,7 @@ SetNPCDialogName: ; 11893 (4:5893)
Func_118a7: ; 118a7 (4:58a7)
push hl
push bc
- call GetNPCDataPointer
+ call GetNPCHeaderPointer
ld bc, $0007
add hl, bc
ld a, [hli]
@@ -929,7 +929,7 @@ Func_118a7: ; 118a7 (4:58a7)
Func_118bf: ; 118bf (4:58bf)
push hl
push bc
- call GetNPCDataPointer
+ call GetNPCHeaderPointer
ld bc, $000a
add hl, bc
ld a, [hli]
@@ -944,7 +944,7 @@ Func_118d3: ; 118d3 (4:58d3)
push hl
push bc
push af
- call GetNPCDataPointer
+ call GetNPCHeaderPointer
ld bc, $000c
add hl, bc
ld a, [hli]
@@ -953,9 +953,9 @@ Func_118d3: ; 118d3 (4:58d3)
cp $2
jr nz, .asm_118f2
ld a, [wCurMap]
- cp $20
+ cp POKEMON_DOME
jr nz, .asm_118f2
- ld a, $17
+ ld a, MUSIC_MATCH_START_3
ld [wMatchStartTheme], a
.asm_118f2